@@ -27,13 +27,9 @@
 
 #include <AkonadiCore/Item>
 
-namespace Akonadi
-{
-namespace Search
-{
-namespace PIM
-{
-
+namespace Akonadi {
+namespace Search {
+namespace PIM {
 class ContactQuery;
 class EmailQuery;
 class NoteQuery;
@@ -58,7 +54,6 @@ private:
     class Private;
     Private *d;
 };
-
 }
 }
 }
