@@ -27,7 +27,8 @@
 #include <KPluginFactory>
 
 K_PLUGIN_FACTORY(PIMContactsRunnerConfigFactory,
-                 registerPlugin<PIMContactsRunnerConfig>(QStringLiteral("kcm_krunner_pimcontacts"));)
+                 registerPlugin<PIMContactsRunnerConfig>(QStringLiteral("kcm_krunner_pimcontacts"));
+                 )
 
 PIMContactsRunnerConfig::PIMContactsRunnerConfig(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
@@ -45,11 +46,7 @@ PIMContactsRunnerConfig::PIMContactsRunnerConfig(QWidget *parent, const QVariant
 
 void PIMContactsRunnerConfig::configChanged()
 {
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 64, 0)
-    Q_EMIT changed();
-#else
     Q_EMIT markAsChanged();
-#endif
 }
 
 void PIMContactsRunnerConfig::load()
